/* 
 * dessine un fleur au milieu du canvas d'id 'zoneDessin'
 */

/**
 * Dessine une ellipse dans un canvas
 * @param {CanvasRenderingContext2D} ctx le contexte graphique du canvas
 * @param {number} cx l'abscisse du centre de l'ellipse
 * @param {number} cy l'ordonnée du centre de l'ellipse
 * @param {number} rx le rayon horizontal de l'ellipse
 * @param {number} ry le rayon vertical de l'ellipse
 * @param {number} angle l'angle (en degrés) de l'ellipse par rapport à l'horizontale
 * @param {string} style le style de tracé (couleur) pour le contour de l'ellipse
 */
function ellipse(ctx, cx, cy, rx, ry, angle, style) {
    ctx.save(); // sauvegarde l'état du contexte graphique
    ctx.beginPath();
    ctx.translate(cx, cy);
    ctx.rotate(angle * Math.PI / 180);
    ctx.scale(rx, ry);
    ctx.arc(0, 0, 1, 0, 2 * Math.PI, false);
    ctx.restore(); // restaure l'état original du contexte graphique
    ctx.save();
    if (style) {
        ctx.strokeStyle = style;
    }
    ctx.stroke();
    ctx.restore();
}

/**
 * dessine un fleur dans un canvas
 * @param {object} ctx le contexte graphique pour dessiner
 * @param {number} cx l'abscisse du centre de la fleur
 * @param {number} cy l'ordonnée du centre de la fleur
 * @param {number} rx le rayon horizontal des ellipses dessiant un pétale
 * @param {number} ry le rayon vertical des ellipses dessiant un pétale
 * @param {type} nbPetales le nombre de pétales
 * @param {type} couleur la couleur du trait pour les pétales
 * @returns {undefined}
 */
function fleur(ctx, cx, cy, rx, ry, nbPetales, couleur) {

    let deltaAngle = 360 / nbPetales;
    for (let i = 1; i <= nbPetales; i++) {
        ellipse(ctx, cx, cy, rx, ry, (i - 1) * deltaAngle, couleur);
    }
}

let canvas = document.getElementById("zoneDessin");
let ctx = canvas.getContext("2d");
fleur(ctx, canvas.width /2, canvas.height / 2, 230, 35, 12, 'red');




